Contributing
============

.. note::

    Here, I explain how to contribute to a project that adopted this template.
    Actually, you can use this same scheme when contributing to this template. If
    you are completely new to ``git`` this might not be the best beginner tutorial,
    but will be very good still ;-)

    You will notice that the text that appears is a mirror of the
    ``CONTRIBUTING.rst`` file. You can also point your community to that file (or
    the docs) to guide them in the steps required to interact with you project.

.. include:: ../CONTRIBUTING.rst
   :start-after: .. start-here
